@@ -1,12 +1,14 @@
-# -*- coding: utf-8 -*-
 # Part of odoo-build.
 # See LICENSE file for full copyright and licensing details.
 
 from argparse import ArgumentParser, RawDescriptionHelpFormatter
 
 import argcomplete
-from __init__ import __version__
+from . import __version__
 
+COPYRIGHT = """
+Copyright (C) 2012-2020 Bluestar Solutions Sàrl (<http://bluestar.solutions>).
+Released under GNU AGPLv3."""
 
 class OBArgumentParser():
     args = None
@@ -15,32 +17,24 @@ class OBArgumentParser():
         parser = ArgumentParser(
             formatter_class=RawDescriptionHelpFormatter,
             description="A developer tool for Odoo.",
-            epilog='''\
+            epilog=f'''\
 goal help:
     %(prog)s <goal> -h
-
-Copyright (C) 2012-2020 Bluestar Solutions Sàrl (<http://bluestar.solutions>).
-Released under GNU AGPLv3.
-            ''',
-            version='''\
-Odoo Build {}
-
-Copyright (C) 2012-2015 Bluestar Solutions Sàrl (<http://bluestar.solutions>).
-Released under GNU AGPLv3.
-            '''.format(__version__))
+{COPYRIGHT}''')
+        parser.add_argument(
+            '--version', action='version',
+            version=f'%(prog)s {__version__}\n{COPYRIGHT}')
 
         parser_shared = ArgumentParser(add_help=False)
 
-        parser_odoo_shared = ArgumentParser(add_help=False)
-        parser_odoo_shared.add_argument(
-            "-t", "--test", dest="odoo_test", action="store_true",
-            help="Run with test configuration.")
-
         subparsers = parser.add_subparsers(metavar="<goal>")
 
         parser_odoo = subparsers.add_parser(
             'odoo', help="Run Odoo server normally.",
-            parents=[parser_shared, parser_odoo_shared])
+            parents=[parser_shared, parser_shared])
+        parser_odoo.add_argument(
+            "-t", "--test", dest="odoo_test", action="store_true",
+            help="Run with test configuration.")
         parser_odoo.add_argument(
             "-u", "--update", dest="odoo_update",
             nargs='?', metavar='all|<module1>[,<module2>…]',
@@ -68,7 +62,7 @@ Released under GNU AGPLv3.
             'project.i18n.export',
             help="Export i18n templates files for addons specified "
             "in project configuration file.",
-            parents=[parser_shared, parser_odoo_shared])
+            parents=[parser_shared])
         parser_i18n_export.add_argument(
             '-d', "--database", dest="database",
             metavar='<database>',
