@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Part of odoo-build.
 # See LICENSE file for full copyright and licensing details.
 
@@ -7,10 +6,6 @@ import subprocess
 from .console import out
 
 
-class CommandError(Exception):
-    pass
-
-
 class Command():
     def __init__(self, *args):
         self.args = args or []
@@ -20,17 +15,13 @@ class Command():
         try:
             process = subprocess.Popen(self.args, **kwargs)
             process.communicate()
-            if process.returncode:
-                out("Command exited with code {}!".format(
-                    process.returncode), 'error')
-                raise CommandError()
         except KeyboardInterrupt:
             try:
                 process.terminate()
                 process.wait()
             except OSError:
                 pass
-            out("Command stopped by keyboard interrupt!", 'warning')
+            out("Odoo stopped by keyboard interrupt!", 'warning')
 
     @staticmethod
     def run(cmd):
