@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Part of odoo-build.
 # See LICENSE file for full copyright and licensing details.
 
@@ -6,7 +5,6 @@ from colorama import Fore, Style
 
 STYLES = {
     'info': Fore.WHITE + Style.BRIGHT,
-    'success': Fore.GREEN + Style.BRIGHT,
     'warning': Fore.YELLOW + Style.BRIGHT,
     'error': Fore.RED + Style.BRIGHT,
     'important': Fore.CYAN + Style.BRIGHT}
@@ -14,4 +12,4 @@ HEAD = Fore.MAGENTA + Style.BRIGHT + '[obuild] ' + Style.RESET_ALL
 
 
 def out(txt, style='none'):
-    print(HEAD + STYLES.get(style, u'') + txt + Style.RESET_ALL)
+    print((HEAD + STYLES.get(style, '') + txt + Style.RESET_ALL))
